<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ta">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="29"/>
        <source>About</source>
        <translation>பற்றி</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="32"/>
        <source>Launch application with image file path as argument to load the file.</source>
        <translation>கோப்பை ஏற்ற வாதமாக பட கோப்பு பாதையுடன் பயன்பாட்டைத் தொடங்கவும்.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="33"/>
        <source>Drag and drop image file onto the window is also supported.</source>
        <translation>படக் கோப்பை சாளரத்தில் இழுத்து விடுங்கள்.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="34"/>
        <source>None of the operations in this application will alter the pictures on disk.</source>
        <translation>இந்த பயன்பாட்டில் உள்ள எந்த செயல்பாடுகளும் வட்டில் உள்ள படங்களை மாற்றாது.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="35"/>
        <source>Context menu option explanation:</source>
        <translation>சூழல் பட்டியல் விருப்பம் விளக்கம்:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="42"/>
        <source>Make window stay on top of all other windows.</source>
        <translation>மற்ற எல்லா சன்னல்களுக்கும் மேலாக சாளரத்தை வைக்கவும்.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="45"/>
        <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
        <translation>தற்செயலாக நெருக்கமான சாளரத்தைத் தவிர்க்கவும். (எ.கா. சாளரத்தை இருமுறை சொடுக்கு செய்வதன் மூலம்)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="48"/>
        <source>Avoid resetting the zoom/rotation/flip state that was applied to the image view when switching between images.</source>
        <translation>படங்களுக்கு இடையில் மாறும்போது படக் காட்சிக்கு பயன்படுத்தப்பட்ட சூம்/சுழற்சி/ஃபிளிப் நிலையை மீட்டமைப்பதைத் தவிர்க்கவும்.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="55"/>
        <source>Version: %1</source>
        <translation>பதிப்பு: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="66"/>
        <source>Logo designed by %1</source>
        <translation>லோகோ %1 ஆல் வடிவமைக்கப்பட்டுள்ளது</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Built with Qt %1 (%2)</source>
        <translation>கியுடி %1 ( %2) உடன் கட்டப்பட்டுள்ளது</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="69"/>
        <source>Source code</source>
        <translation>மூலக் குறியீடு</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="79"/>
        <source>Contributors</source>
        <translation>பங்களிப்பாளர்கள்</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>List of contributors on GitHub</source>
        <translation>கிதுபில் பங்களிப்பாளர்களின் பட்டியல்</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>Thanks to all people who contributed to this project.</source>
        <translation>இந்த திட்டத்திற்கு பங்களித்த அனைத்து மக்களுக்கும் நன்றி.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="86"/>
        <source>Translators</source>
        <translation>மொழிபெயர்ப்பாளர்கள்</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="87"/>
        <source>I would like to thank the following people who volunteered to translate this application.</source>
        <translation>இந்த விண்ணப்பத்தை மொழிபெயர்க்க முன்வந்த பின்வரும் நபர்களுக்கு நன்றி தெரிவிக்க விரும்புகிறேன்.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="131"/>
        <source>%1 is built on the following free software libraries:</source>
        <comment>Free as in freedom</comment>
        <translation>%1 பின்வரும் இலவச மென்பொருள் நூலகங்களில் கட்டப்பட்டுள்ளது:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="155"/>
        <source>&amp;Special Thanks</source>
        <translation>&amp; சிறப்பு நன்றி</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="157"/>
        <source>&amp;Third-party Libraries</source>
        <translation>மூன்றாம் தரப்பு நூலகங்கள்</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>Your Rights</source>
        <translation>உங்கள் உரிமைகள்</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Copyright (c) %1 %2</source>
        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
        <translation>பதிப்புரிமை (சி) %1 %2</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="95"/>
        <source>%1 is released under the MIT License.</source>
        <translation>%1 எம்ஐடி உரிமத்தின் கீழ் வெளியிடப்படுகிறது.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="96"/>
        <source>This license grants people a number of freedoms:</source>
        <translation>இந்த உரிமம் மக்களுக்கு பல சுதந்திரங்களை வழங்குகிறது:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="97"/>
        <source>You are free to use %1, for any purpose</source>
        <translation>எந்தவொரு நோக்கத்திற்காகவும் நீங்கள் %1 ஐப் பயன்படுத்த இலவசம்</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="98"/>
        <source>You are free to distribute %1</source>
        <translation>%1 ஐ விநியோகிக்க நீங்கள் இலவசம்</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="99"/>
        <source>You can study how %1 works and change it</source>
        <translation>%1 எவ்வாறு செயல்படுகிறது என்பதைப் படித்து அதை மாற்றலாம்</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="100"/>
        <source>You can distribute changed versions of %1</source>
        <translation>மாற்றப்பட்ட பதிப்புகளை %1 இன் விநியோகிக்கலாம்</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="102"/>
        <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
        <translation>எம்ஐடி உரிமம் இந்த சுதந்திரத்தை உங்களுக்கு பொறுப்பு செய்கிறது. அதை எடுத்துச் செல்ல யாரும் அனுமதிக்கப்படுவதில்லை.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="130"/>
        <source>Third-party Libraries used by %1</source>
        <translation>%1 ஆல் பயன்படுத்தப்படும் மூன்றாம் தரப்பு நூலகங்கள்</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="153"/>
        <source>&amp;Help</source>
        <translation>உதவி (&amp;h)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="154"/>
        <source>&amp;About</source>
        <translation>&amp;பற்றி</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="156"/>
        <source>&amp;License</source>
        <translation>&amp; உரிமம்</translation>
    </message>
</context>
<context>
    <name>GraphicsScene</name>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../graphicsscene.cpp" line="102"/>
        <source>Drag image here</source>
        <translation>படத்தை இங்கே இழுக்கவும்</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../graphicsview.cpp" line="51"/>
        <source>File is not a valid image</source>
        <translation>கோப்பு சரியான படம் அல்ல</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="55"/>
        <location filename="../graphicsview.cpp" line="60"/>
        <location filename="../graphicsview.cpp" line="71"/>
        <source>Image data is invalid or currently unsupported</source>
        <translation>படத் தரவு தவறானது அல்லது தற்போது ஆதரிக்கப்படாதது</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <location filename="../mainwindow.cpp" line="561"/>
        <source>File url list is empty</source>
        <translation>கோப்பு முகவரி பட்டியல் காலியாக உள்ளது</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>&amp;Copy</source>
        <translation>நகலெடு (&amp;c)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Image data is invalid</source>
        <translation>படத் தரவு தவறானது</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <source>Not supported mimedata: %1</source>
        <translation>மைமெடாட்டாவை ஆதரிக்கவில்லை: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="783"/>
        <source>Image From Clipboard</source>
        <translation>கிளிப்போர்டிலிருந்து படம்</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>Are you sure you want to move &quot;%1&quot; to recycle bin?</source>
        <translation>பின் மறுசுழற்சி செய்ய &quot;%1&quot; ஐ நகர்த்த விரும்புகிறீர்களா?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="805"/>
        <source>Failed to move file to trash</source>
        <translation>கோப்பை குப்பைக்கு நகர்த்துவதில் தோல்வி</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="806"/>
        <source>Move to trash failed, it might caused by file permission issue, file system limitation, or platform limitation.</source>
        <translation>குப்பைக்கு நகர்வது தோல்வியுற்றது, இது கோப்பு இசைவு சிக்கல், கோப்பு முறைமை வரம்பு அல்லது இயங்குதள வரம்பு ஆகியவற்றால் ஏற்படலாம்.</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="106"/>
        <source>Copy P&amp;ixmap</source>
        <translation>பி &amp; ஐஎக்ச்மேப்பை நகலெடுக்கவும்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="107"/>
        <source>Copy &amp;File Path</source>
        <translation>கோப்பு பாதையை நகலெடுக்கவும்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="125"/>
        <source>Properties</source>
        <translation>பண்புகள்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="110"/>
        <location filename="../aboutdialog.cpp" line="41"/>
        <source>Stay on top</source>
        <translation>மேலே இருங்கள்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="111"/>
        <location filename="../aboutdialog.cpp" line="44"/>
        <source>Protected mode</source>
        <translation>பாதுகாக்கப்பட்ட பயன்முறை</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="112"/>
        <location filename="../aboutdialog.cpp" line="47"/>
        <source>Keep transformation</source>
        <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
        <translation>மாற்றத்தைத் தொடருங்கள்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>Zoom in</source>
        <translation>பெரிதாக்கு</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>Zoom out</source>
        <translation>சிறிதாக்கு</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="99"/>
        <source>Pause/Resume Animation</source>
        <translation>இடைநிறுத்தம்/அனிமேசனை மீண்டும் தொடங்குங்கள்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="100"/>
        <source>Animation Go to Next Frame</source>
        <translation>அனிமேசன் அடுத்த சட்டகத்திற்குச் செல்லுங்கள்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="102"/>
        <source>Flip &amp;Horizontally</source>
        <translation>கிடைமட்டமாக புரட்டவும்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="103"/>
        <source>Fit to view</source>
        <translation>பார்க்க பொருத்தமானது</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="104"/>
        <source>Fit to width</source>
        <translation>அகலத்திற்கு ஏற்றது</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="105"/>
        <source>Fit long image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="108"/>
        <source>&amp;Paste</source>
        <translation>ஒட்டு (&amp;p)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>Toggle Checkerboard</source>
        <translation>செக்கர்போர்டை மாற்றவும்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>&amp;Open...</source>
        <translation>&amp; திறந்த ...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>Actual size</source>
        <translation>உண்மையான அளவு</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>Toggle maximize</source>
        <translation>அதிகபட்சத்தை மாற்றவும்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="93"/>
        <source>Rotate right</source>
        <translation>வலதுபுறம் சுழற்றுங்கள்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="94"/>
        <source>Rotate left</source>
        <translation>இடதுபுறம் சுழலும்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="96"/>
        <source>Previous image</source>
        <translation>முந்தைய படம்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="97"/>
        <source>Next image</source>
        <translation>அடுத்த படம்</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="800"/>
        <location filename="../actionmanager.cpp" line="109"/>
        <source>Move to Trash</source>
        <translation>குப்பைக்கு நகர்த்தவும்</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="113"/>
        <source>Configure...</source>
        <translation>உள்ளமைக்கவும் ...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="114"/>
        <source>Help</source>
        <translation>உதவி</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="117"/>
        <source>Show in File Explorer</source>
        <comment>File Explorer is the name of explorer.exe under Windows</comment>
        <translation>கோப்பு எக்ச்ப்ளோரரில் காண்பி</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="123"/>
        <source>Show in directory</source>
        <translation>கோப்பகத்தில் காட்டு</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="126"/>
        <source>Quit</source>
        <translation>வெளியேறு</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="../metadatadialog.cpp" line="84"/>
        <source>Image Metadata</source>
        <translation>பட மேனிலை தரவு</translation>
    </message>
</context>
<context>
    <name>MetadataModel</name>
    <message>
        <location filename="../metadatamodel.cpp" line="43"/>
        <source>Origin</source>
        <comment>Section name.</comment>
        <translation>தோற்றம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="44"/>
        <source>Image</source>
        <comment>Section name.</comment>
        <translation>படம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="48"/>
        <source>File</source>
        <comment>Section name.</comment>
        <translation>கோப்பு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="45"/>
        <source>Camera</source>
        <comment>Section name.</comment>
        <translation>கேமரா</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="35"/>
        <source>%1 File</source>
        <translation>%1 கோப்பு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="42"/>
        <source>Description</source>
        <comment>Section name.</comment>
        <translation>விவரம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="46"/>
        <source>Advanced photo</source>
        <comment>Section name.</comment>
        <translation>மேம்பட்ட புகைப்படம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="47"/>
        <source>GPS</source>
        <comment>Section name.</comment>
        <translation>உலக இடம் காட்டும் அமைப்பு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="52"/>
        <source>Dimensions</source>
        <translation>பரிமாணங்கள்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="54"/>
        <source>Aspect ratio</source>
        <translation>அம்ச விகிதம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="58"/>
        <source>Frame count</source>
        <translation>சட்ட எண்ணிக்கை</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="62"/>
        <source>Name</source>
        <translation>பெயர்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="64"/>
        <source>Item type</source>
        <translation>உருப்படி வகை</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="66"/>
        <source>Folder path</source>
        <translation>கோப்புறை பாதை</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="68"/>
        <source>Size</source>
        <translation>அளவு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="70"/>
        <source>Date created</source>
        <translation>தேதி உருவாக்கப்பட்டது</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="72"/>
        <source>Date modified</source>
        <translation>தேதி மாற்றியமைக்கப்பட்டது</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="79"/>
        <source>Title</source>
        <translation>தலைப்பு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="81"/>
        <source>Subject</source>
        <translation>பொருள்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="83"/>
        <source>Rating</source>
        <translation>செயல்வரம்பு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="85"/>
        <source>Tags</source>
        <translation>குறிச்சொற்கள்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="87"/>
        <source>Comments</source>
        <translation>கருத்துகள்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="90"/>
        <source>Authors</source>
        <translation>ஆசிரியர்கள்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="92"/>
        <source>Date taken</source>
        <translation>எடுக்கப்பட்ட தேதி</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="98"/>
        <source>Program name</source>
        <translation>நிரல் பெயர்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="100"/>
        <source>Copyright</source>
        <translation>பதிப்புரிமை</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="103"/>
        <source>Horizontal resolution</source>
        <translation>கிடைமட்ட தீர்மானம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="105"/>
        <source>Vertical resolution</source>
        <translation>செங்குத்து தீர்மானம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="107"/>
        <source>Resolution unit</source>
        <translation>தெளிவுத்திறன் அலகு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="109"/>
        <source>Colour representation</source>
        <translation>வண்ண பிரதிநிதித்துவம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="112"/>
        <source>Camera maker</source>
        <translation>கேமரா தயாரிப்பாளர்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="114"/>
        <source>Camera model</source>
        <translation>கேமரா மாதிரி</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="116"/>
        <source>F-stop</source>
        <translation>எஃப்-ச்டாப்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="118"/>
        <source>Exposure time</source>
        <translation>நேரிடுதல் காலம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="120"/>
        <source>ISO speed</source>
        <translation>ஐஎச்ஓ விரைவு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="122"/>
        <source>Exposure bias</source>
        <translation>வெளிப்பாடு சார்பு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="124"/>
        <source>Focal length</source>
        <translation>குவிநீளம், குவியத் தொலைவு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="126"/>
        <source>Max aperture</source>
        <translation>அதிகபட்ச துளை</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="128"/>
        <source>Metering mode</source>
        <translation>அளவீட்டு முறை</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="130"/>
        <source>Subject distance</source>
        <translation>பொருள் தூரம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="132"/>
        <source>Flash mode</source>
        <translation>ஃபிளாச் பயன்முறை</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="134"/>
        <source>35mm focal length</source>
        <translation>35 மிமீ குவிய நீளம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="137"/>
        <source>Lens model</source>
        <translation>லென்ச் மாதிரி</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="139"/>
        <source>Contrast</source>
        <translation>மாறுபாடு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="141"/>
        <source>Brightness</source>
        <translation>ஒளி</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="143"/>
        <source>Exposure program</source>
        <translation>வெளிப்பாடு திட்டம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="145"/>
        <source>Saturation</source>
        <translation>தெவிட்டல்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="147"/>
        <source>Sharpness</source>
        <translation>கூர்மையானது</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="149"/>
        <source>White balance</source>
        <translation>வெள்ளை இருப்பு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="151"/>
        <source>Digital zoom</source>
        <translation>டிசிட்டல் சூம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="153"/>
        <source>EXIF version</source>
        <translation>Exif பதிப்பு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="156"/>
        <source>Latitude reference</source>
        <translation>அட்சரேகை குறிப்பு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="158"/>
        <source>Latitude</source>
        <translation>அகலாங்கு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="160"/>
        <source>Longitude reference</source>
        <translation>தீர்க்கரேகை குறிப்பு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="162"/>
        <source>Longitude</source>
        <translation>நெட்டாங்கு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="164"/>
        <source>Altitude reference</source>
        <translation>உயர குறிப்பு</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="166"/>
        <source>Altitude</source>
        <translation>குத்துயரம்</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="176"/>
        <source>%1 x %2</source>
        <translation>%1 ஃச் %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="194"/>
        <source>%1 : %2</source>
        <translation>%1: %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Property</source>
        <translation>சொத்து</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Value</source>
        <translation>மதிப்பு</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Settings</source>
        <translation>அமைப்புகள்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>Options</source>
        <translation>விருப்பங்கள்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <source>Shortcuts</source>
        <translation>குறுக்குவழிகள்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="63"/>
        <source>Editing shortcuts for action &quot;%1&quot;:</source>
        <translation>செயலுக்கான குறுக்குவழிகளைத் திருத்துதல் &quot;%1&quot;:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="72"/>
        <source>Failed to set shortcuts</source>
        <translation>குறுக்குவழிகளை அமைப்பதில் தோல்வி</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="73"/>
        <source>Please check if shortcuts are duplicated with existing shortcuts.</source>
        <translation>தற்போதுள்ள குறுக்குவழிகளுடன் குறுக்குவழிகள் நகல் செய்யப்பட்டுள்ளதா என்று சரிபார்க்கவும்.</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Do nothing</source>
        <translation>எதுவும் செய்ய வேண்டாம்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="81"/>
        <source>Close the window</source>
        <translation>சாளரத்தை மூடு</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="82"/>
        <source>Toggle maximize</source>
        <translation>அதிகபட்சத்தை மாற்றவும்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="83"/>
        <source>Toggle fullscreen</source>
        <translation>மாற்று முழுத்திரை</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="87"/>
        <source>Zoom in and out</source>
        <translation>உள்ளேயும் வெளியேயும் பெரிதாக்கவும்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="88"/>
        <source>View next or previous item</source>
        <translation>அடுத்த அல்லது முந்தைய உருப்படியைக் காண்க</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="92"/>
        <source>Auto size</source>
        <translation>வாகன அளவு</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="93"/>
        <source>Maximized</source>
        <translation>அதிகபட்சம்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="94"/>
        <source>Windowed</source>
        <translation>சாளரம்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="98"/>
        <source>Round (Integer scaling)</source>
        <comment>This option means round up for .5 and above</comment>
        <translation>சுற்று (முழு எண் அளவிடுதல்)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="99"/>
        <source>Ceil (Integer scaling)</source>
        <comment>This option means always round up</comment>
        <translation>சீல் (முழு எண் அளவிடுதல்)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="100"/>
        <source>Floor (Integer scaling)</source>
        <comment>This option means always round down</comment>
        <translation>மாடி (முழு எண் அளவிடுதல்)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="101"/>
        <source>Follow system (Fractional scaling)</source>
        <comment>This option means don&apos;t round</comment>
        <translation>கணினியைப் பின்பற்றவும் (பகுதியளவு அளவிடுதல்)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="124"/>
        <source>Stay on top when start-up</source>
        <translation>தொடக்கத்தில் இருக்கும்போது மேலே இருங்கள்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="125"/>
        <source>Use built-in close window animation</source>
        <translation>உள்ளமைக்கப்பட்ட நெருக்கமான சாளர அனிமேஷனைப் பயன்படுத்தவும்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="126"/>
        <source>Use light-color checkerboard</source>
        <translation>ஒளி-வண்ண செக்கர்போர்டைப் பயன்படுத்தவும்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="127"/>
        <source>Loop the loaded gallery</source>
        <translation>ஏற்றப்பட்ட கேலரியை சுற்றுங்கள்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="128"/>
        <source>Auto long image mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="129"/>
        <source>Limit SVG support to SVG Tiny 1.2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="130"/>
        <source>Double-click behavior</source>
        <translation>நடத்தை இருமுறை சொடுக்கு செய்யவும்</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="131"/>
        <source>Mouse wheel behavior</source>
        <translation>சுட்டி சக்கர நடத்தை</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="132"/>
        <source>Default window size</source>
        <translation>இயல்புநிலை சாளர அளவு</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="133"/>
        <source>HiDPI scale factor rounding policy</source>
        <translation>HIDPI அளவிலான காரணி ரவுண்டிங் கொள்கை</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../shortcutedit.cpp" line="104"/>
        <source>No shortcuts</source>
        <translation>குறுக்குவழிகள் இல்லை</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <location filename="../shortcutedit.cpp" line="70"/>
        <source>Shortcut #%1</source>
        <translation>குறுக்குவழி #%1</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Pineapple Pictures</source>
        <translation>அன்னாசி படங்கள்</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>List supported image format suffixes, and quit program.</source>
        <translation>ஆதரிக்கப்பட்ட பட வடிவமைப்பு பின்னொட்டுகளை பட்டியலிடுங்கள், மற்றும் நிரல் வெளியேறுதல்.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>File list.</source>
        <translation>கோப்பு பட்டியல்.</translation>
    </message>
</context>
</TS>
